@@ -6,10 +6,10 @@ from PIL import Image
 import numpy
 import glob
 import itertools
+import logging
 
 import amulet_nbt
 
-from minecraft_model_reader import log
 from minecraft_model_reader.api import Block
 from minecraft_model_reader.api.resource_pack import BaseResourcePackManager
 from minecraft_model_reader.api.resource_pack.java import JavaResourcePack
@@ -21,6 +21,8 @@ from minecraft_model_reader.api.mesh.block.cube import (
     tri_face,
 )
 
+log = logging.getLogger(__name__)
+
 
 UselessImageGroups = {
     "colormap",
@@ -238,7 +240,7 @@ class JavaResourcePackManager(BaseResourcePackManager):
                             block.properties.get(
                                 match.group("name"),
                                 amulet_nbt.TAG_String(match.group("value")),
-                            ).value
+                            ).py_data
                             == match.group("value")
                             for match in properties_match
                         ):
@@ -352,7 +354,7 @@ class JavaResourcePackManager(BaseResourcePackManager):
             corners = numpy.sort(
                 numpy.array(
                     [element.get("to", [16, 16, 16]), element.get("from", [0, 0, 0])],
-                    numpy.float,
+                    float,
                 )
                 / 16,
                 0,
@@ -408,7 +410,7 @@ class JavaResourcePackManager(BaseResourcePackManager):
                     texture_uv = (
                         numpy.array(
                             element_faces[face_dir].get("uv", [0, 0, 16, 16]),
-                            numpy.float,
+                            float,
                         )
                         / 16
                     )
